from scadnano import Modification5Prime, Modification3Prime, ModificationInternal

biotin_5p = Modification5Prime(display_text='B', id='/5Biosg/', idt_text='/5Biosg/')
biotin_3p = Modification3Prime(display_text='B', id='/3Bio/', idt_text='/3Bio/')
biotin_int = ModificationInternal(display_text='B', id='/iBiodT/', idt_text='/iBiodT/',
                                  allowed_bases=frozenset('T'))

cy3_5p = Modification5Prime(display_text='Cy3', id='/5Cy3/', idt_text='/5Cy3/')
cy3_3p = Modification3Prime(display_text='Cy3', id='/3Cy3Sp/', idt_text='/3Cy3Sp/')
cy3_int = ModificationInternal(display_text='Cy3', id='/iCy3/', idt_text='/iCy3/')

cy5_5p = Modification5Prime(display_text='Cy5', id='/5Cy5/', idt_text='/5Cy5/')
cy5_3p = Modification3Prime(display_text='Cy5', id='/3Cy5Sp/', idt_text='/3Cy5Sp/')
cy5_int = ModificationInternal(display_text='Cy5', id='/iCy5/', idt_text='/iCy5/')



"""Version information."""
# taken from https://stackoverflow.com/questions/17583443/what-is-the-correct-way-to-share-package-version-with-setup-py-and-the-package/17626524#17626524

# The following line *must* be the last in the module, exactly as formatted:
# XXX: REMEMBER TO CHANGE VERSION IN scadnano.py also, for users who do not install from PyPI
__version__ = "0.9.9"



#!/usr/bin/env python

# from distutils.core import setup

# got some ideas from here: https://medium.com/@joel.barmettler/how-to-upload-your-python-package-to-pypi-65edc5fe9c56
#
# But apparently setuptools is the replacement for distutils, and distutils was causing problems such as
# not including the README.md file and not formatting it as Markdown on PyPI
# https://setuptools.readthedocs.io/en/latest/setuptools.html

from setuptools import setup

# import scadnano.scadnano_version as sv

# from scadnano.scadnano_version import current_version
# this is ugly, but appears to be standard practice:
# https://stackoverflow.com/questions/17583443/what-is-the-correct-way-to-share-package-version-with-setup-py-and-the-package/17626524#17626524
__version__ = open("scadnano/_version.py").readlines()[-1].split()[-1].strip("\"'")

# read the contents of your README file
from os import path

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(name='scadnano',
      packages=['scadnano'],
      version=__version__,
      # version='0.8.0',
      download_url=f'https://github.com/UC-Davis-molecular-computing/scadnano-python-package/archive/v{__version__}.zip',
      # download_url=f'https://github.com/UC-Davis-molecular-computing/scadnano-python-package/archive/v0.7.0.zip',
      license='MIT',
      description="Python scripting library for generating designs readable by scadnano.",
      author="David Doty",
      author_email="doty@ucdavis.edu",
      url="https://github.com/UC-Davis-molecular-computing/scadnano-python-package",
      long_description=long_description,
      long_description_content_type='text/markdown; variant=GFM',
      requires=['xlwt']
      )
